@@ -3,12 +3,14 @@ from allure_commons._allure import description, description_html
 from allure_commons._allure import label
 from allure_commons._allure import severity
 from allure_commons._allure import tag
+from allure_commons._allure import id
 from allure_commons._allure import suite, parent_suite, sub_suite
 from allure_commons._allure import epic, feature, story
 from allure_commons._allure import link, issue, testcase
 from allure_commons._allure import Dynamic as dynamic
 from allure_commons._allure import step
 from allure_commons._allure import attach
+from allure_commons._allure import manual
 from allure_commons.types import Severity as severity_level
 from allure_commons.types import AttachmentType as attachment_type
 
@@ -23,6 +25,7 @@ __all__ = [
     'parent_suite',
     'sub_suite',
     'tag',
+    'id',
     'epic',
     'feature',
     'story',
@@ -33,5 +36,6 @@ __all__ = [
     'dynamic',
     'severity_level',
     'attach',
-    'attachment_type'
+    'attachment_type',
+    'manual'
 ]
